@@ -14,7 +14,7 @@ def timestampMillisec64():
 
 
 class ChaosException(Exception):
-    """Exception raised for rest exception.
+    """ Chaos Error/Exception raised for rest exception.
 
     Attributes:
         message -- explanation of the error
@@ -24,6 +24,15 @@ class ChaosException(Exception):
         self.message = message
 
 def basicPost(func,params):
+    """ Basic post for chaos rest calls
+    Args:
+        func: string that defines the target function (CU or MDS (administration))
+        params: dict with parameters
+    
+    Raises:
+        ChaosException in case of error from !CHAOS or other exception if communication error
+
+    """
     srv = options["uri"];
     url = "http://" + srv + "/" + func;
     r = requests.post(url, data=params, headers={'Content-Type': 'application/x-www-form-urlencoded'})
@@ -33,5 +42,14 @@ def basicPost(func,params):
         raise ChaosException(r.text)
   
 def mdsBase(cmd,opt):
+    """ base function for MDS administration 
+
+    Arguments:
+        cmd {[string]} -- commands
+        opt {[dict]} -- parameters
+
+    Returns:
+        [dict] -- an object depending from the operation
+    """    
     param = "cmd=" + cmd + "&parm=" + json.dumps(opt)
     return basicPost("MDS", param)
