@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 import pychaos
 import sys
 import time
@@ -31,7 +32,8 @@ try:
             print(ps_all)
             break;
         else:
-            print(".", end = '',flush=True)
+            print("."),
+            sys.stdout.flush()
 
 
 except pychaos.ChaosException as err:
